@@ -4,14 +4,23 @@ OC.L10N.register(
     "Contacts" : "جهات الاتصال",
     "All contacts" : "كل الجهات",
     "Details" : "التفاصيل",
+    "Add a new picture" : "إضافة صورة جديدة",
+    "Upload a new picture" : "تحميل صورة جديدة",
+    "Delete picture" : "حذف الصورة",
+    "Download picture" : "تنزيل الصورة",
+    "Name" : "الاسم",
+    "Company" : "الشركة",
+    "Title" : "العنوان",
     "Download" : "تحميل",
     "Delete" : "حذف",
+    "Addressbook" : "دفتر العناوين",
     "Groups" : "مجموعات",
     "New contact" : "جهة إتصال جديدة",
-    "Copy link" : "نسخ الرابط",
     "Rename" : "تعديل الإسم",
+    "Copy link" : "نسخ الرابط",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
     "Import into" : "إستيراد إلى",
+    "Address book name" : "اسم دفتر العناوين",
     "First name" : "الإسم",
     "Last name" : "اللقب",
     "Nickname" : "كنية.\nلقب.",
