@@ -7,21 +7,29 @@ OC.L10N.register(
     "A contacts app for Nextcloud" : "Yhteystietosovellus Nextcloudille",
     "Add new property" : "Lisää uusi ominaisuus",
     "Choose property type" : "Valitse ominaisuuden tyyppi",
+    "Add a new picture" : "Lisää uusi kuva",
     "Upload a new picture" : "Lähetä uusi kuva",
+    "Choose from files" : "Valitse tiedostoista",
+    "Delete picture" : "Poista kuva",
+    "Download picture" : "Lataa kuva",
     "Image is too big (max 1MB)." : "Kuva on liian suuri (enintään 1 Mt).",
+    "Pick an avatar" : "Valitse avatar",
+    "Error while processing the picture." : "Virhe kuvan käsittelyn aikana.",
     "No contact selected" : "Yhteystietoa ei ole valittu",
     "Select a contact on the list to begin" : "Valitse yhteystieto luettelosta aloittaaksesi",
     "Loading" : "Ladataan",
     "Name" : "Nimi",
     "Company" : "Yritys",
     "Title" : "Nimeke",
+    "Download" : "Lataa",
+    "Generate QR Code" : "Luo QR-koodi",
+    "Delete" : "Poista",
     "This contact is not yet synced. Edit it to save it to the server." : "Tätä yhteystietoa ei ole vielä synkronoitu. Muokkaa yhteystietoa tallentaaksesi sen palvelimelle.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Tämä yhteystieto on \"vain luku\"-tilassa. Sinulla ei ole oikeuksia muokata tätä yhteystietoa.",
-    "Download" : "Lataa",
-    "Delete" : "Poista",
     "Addressbook" : "Osoitekirja",
     "Groups" : "Ryhmät",
     "New contact" : "Uusi yhteystieto",
+    "Deleting the contact in {countdown} seconds" : "Poistetaan yhteystieto {countdown} sekunnin kuluttua",
     "No errors" : "Ei virheitä",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} virheellinen yhteystieto","{failedCount} virheellistä yhteystietoa"],
@@ -31,12 +39,12 @@ OC.L10N.register(
     "No results" : "Ei tuloksia",
     "Last modified" : "Viimeksi muokattu",
     "Select option" : "Valitse valinta",
-    "Copy link" : "Kopioi linkki",
-    "Copied" : "Kopioitu",
-    "Can not copy" : "Ei voida kopioida",
     "Rename" : "Nimeä uudelleen",
     "Enabled" : "Käytössä",
     "Disabled" : "Pois käytöstä",
+    "Copied" : "Kopioitu",
+    "Can not copy" : "Ei voida kopioida",
+    "Copy link" : "Kopioi linkki",
     "This will delete the addressbook and every contacts within it" : "Tämä poistaa osoitekirjan ja kaikki siinä olevat yhteystiedot",
     "Delete {addressbook} ?" : "Poistetaanko {addressbook} ?",
     "Deletion of addressbook was not successful." : "Osoitekirjan poistaminen ei onnistunut.",
@@ -116,6 +124,8 @@ OC.L10N.register(
     "Female" : "Nainen",
     "Male" : "Mies",
     "Unknown" : "Tuntematon",
-    "An error occurred" : "Tapahtui virhe"
+    "An error occurred" : "Tapahtui virhe",
+    "Your web browser is out of date" : "Käyttämäsi selain on vanhentunut",
+    "This application is not compatible with Internet Explorer" : "Tämä sovellus ei ole yhteensopiva Internet Explorerin kanssa"
 },
 "nplurals=2; plural=(n != 1);");
