@@ -8,7 +8,11 @@ OC.L10N.register(
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
     "Add new property" : "新しいプロパティを追加する",
     "Choose property type" : "プロパティの種類を選択",
+    "Add a new picture" : "画像を追加",
     "Upload a new picture" : "新しい写真をアップロードする",
+    "Choose from files" : "ファイルから選択",
+    "Delete picture" : "画像を削除",
+    "Download picture" : "画像をダウンロード",
     "Image is too big (max 1MB)." : "画像容量が大きすぎます (最大1 MB)",
     "No contact selected" : "連絡先が選択されていません",
     "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
@@ -16,11 +20,11 @@ OC.L10N.register(
     "Name" : "名前",
     "Company" : "会社",
     "Title" : "タイトル",
+    "Download" : "ダウンロード",
+    "Delete" : "削除",
     "This contact is not yet synced. Edit it to save it to the server." : "この連絡先はまだ同期されていません。 それを編集してサーバーに保存して下さい。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
-    "Download" : "ダウンロード",
-    "Delete" : "削除",
     "Addressbook" : "アドレス帳",
     "Groups" : "グループ",
     "New contact" : "新しい連絡先",
@@ -31,12 +35,12 @@ OC.L10N.register(
     "Add contact in group" : "グループに連絡先を追加",
     "No results" : "該当なし",
     "Select option" : "オプションを選択",
-    "Copy link" : "リンクをコピー",
-    "Copied" : "コピーしました",
-    "Can not copy" : "コピーできません",
     "Rename" : "名前を変更",
     "Enabled" : "有効",
     "Disabled" : "無効",
+    "Copied" : "コピーしました",
+    "Can not copy" : "コピーできません",
+    "Copy link" : "リンクをコピー",
     "Enabled toggle of addressbook was not successful." : "アドレス帳の有効なトグルが成功しませんでした。",
     "Deletion of addressbook was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of addressbook was not successful." : "アドレス帳の名前を変更できませんでした。",
