@@ -13,10 +13,10 @@ OC.L10N.register(
     "Error while processing the picture." : "Klaida apdorojant paveikslėlį.",
     "No contact selected" : "Nepasirinktas joks adresatas",
     "Loading" : "Įkeliama",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
     "Download" : "Atsisiųsti",
     "Generate QR Code" : "Generuoti QR kodą",
     "Delete" : "Ištrinti",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
     "Addressbook" : "Adresų knyga",
     "Groups" : "Grupės",
     "New contact" : "Naujas adresatas",
@@ -25,12 +25,12 @@ OC.L10N.register(
     "No errors" : "Klaidų nėra",
     "Open your browser console for more details" : "Išsamesnei informacijai, atverkite savo naršyklės pultą",
     "No results" : "Rezultatų nėra",
-    "Copy link" : "Kopijuoti nuorodą",
-    "Copied" : "Nukopijuota",
-    "Can not copy" : "Nepavyksta nukopijuoti",
     "Rename" : "Pervadinti",
     "Enabled" : "Įjungta",
     "Disabled" : "Išjungta",
+    "Copied" : "Nukopijuota",
+    "Can not copy" : "Nepavyksta nukopijuoti",
+    "Copy link" : "Kopijuoti nuorodą",
     "This will delete the addressbook and every contacts within it" : "Tai ištrins adresų knygą ir visus joje esančius adresatus",
     "Delete {addressbook} ?" : "Ištrinti {addressbook} ?",
     "Deletion of addressbook was not successful." : "Adresų knygos ištrynimas buvo nesėkmingas.",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Addressbook copied to clipboard" : "Adresų knyga nukopijuota į iškarpinę",
     "Addressbook was not copied to clipboard." : "Adresų knyga nebuvo nukopijuota į iškarpinę.",
     "Share with users or groups" : "Dalintis su naudotojais ar grupėmis",
+    "No users or groups" : "Nėra jokių naudotojų ar grupių",
     "can edit" : "gali keisti",
     "Unable to delete the share." : "Nepavyko ištrinti viešinio.",
     "Unable to change permissions." : "Nepavyko pakeisti leidimų.",
@@ -98,6 +99,8 @@ OC.L10N.register(
     "None" : "Nėra",
     "Unknown" : "Nežinoma",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nepavyko perskaityti {failed} adresato","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresato"],
-    "An error occurred" : "Įvyko klaida"
+    "An error occurred" : "Įvyko klaida",
+    "Your web browser is out of date" : "Jūsų saityno naršyklė yra pasenusi",
+    "This application is not compatible with Internet Explorer" : "Ši programa nėra suderinama su Internet Explorer"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
