@@ -21,12 +21,12 @@ OC.L10N.register(
     "Name" : "Namn",
     "Company" : "Företag",
     "Title" : "Titel",
-    "This contact is not yet synced. Edit it to save it to the server." : "Den här kontakten är ännu inte synkroniserad. Redigera den för att spara på servern.",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
     "Download" : "Ladda ned",
     "Generate QR Code" : "Generera QR-kod",
     "Delete" : "Radera",
+    "This contact is not yet synced. Edit it to save it to the server." : "Den här kontakten är ännu inte synkroniserad. Redigera den för att spara på servern.",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
     "Addressbook" : "Adressbok",
     "Groups" : "Grupper",
     "New contact" : "Ny kontakt",
@@ -43,12 +43,12 @@ OC.L10N.register(
     "No results" : "Inga resultat",
     "Last modified" : "Senast ändrad",
     "Select option" : "Välj alternativ",
-    "Copy link" : "Kopiera länk",
-    "Copied" : "Kopierad",
-    "Can not copy" : "Kunde inte kopiera",
     "Rename" : "Byt namn",
     "Enabled" : "Aktiverad",
     "Disabled" : "Inaktiverad",
+    "Copied" : "Kopierad",
+    "Can not copy" : "Kunde inte kopiera",
+    "Copy link" : "Kopiera länk",
     "Enabled toggle of addressbook was not successful." : "Aktiverad växling av adressboken lyckades inte.",
     "This will delete the addressbook and every contacts within it" : "Detta tar bort adressboken och alla kontakter i den",
     "Delete {addressbook} ?" : "Radera {addressbook} ?",
@@ -138,6 +138,8 @@ OC.L10N.register(
     "None" : "Ingen",
     "Unknown" : "Okänd",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunde inte läsas","{failed} kontakter kunde inte läsas"],
-    "An error occurred" : "Ett fel uppstod"
+    "An error occurred" : "Ett fel uppstod",
+    "Your web browser is out of date" : "Din webbläsare är för gammal",
+    "This application is not compatible with Internet Explorer" : "Den här applikationen är inte kompatibel med Internet Explorer"
 },
 "nplurals=2; plural=(n != 1);");
