@@ -22,12 +22,12 @@ OC.L10N.register(
     "Name" : "名称",
     "Company" : "公司",
     "Title" : "头衔",
-    "This contact is not yet synced. Edit it to save it to the server." : "此联系人尚未同步。 编辑它以将其保存到服务器。",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Download" : "下载",
     "Generate QR Code" : "生成二维码",
     "Delete" : "删除",
+    "This contact is not yet synced. Edit it to save it to the server." : "此联系人尚未同步。 编辑它以将其保存到服务器。",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Addressbook" : "地址簿",
     "Groups" : "群组",
     "New contact" : "新建联系人",
@@ -44,12 +44,12 @@ OC.L10N.register(
     "No results" : "无结果",
     "Last modified" : "上一次更改",
     "Select option" : "选择选项",
-    "Copy link" : "复制链接",
-    "Copied" : "已复制",
-    "Can not copy" : "无法复制",
     "Rename" : "重命名",
     "Enabled" : "已启用",
     "Disabled" : "已禁用",
+    "Copied" : "已复制",
+    "Can not copy" : "无法复制",
+    "Copy link" : "复制链接",
     "Enabled toggle of addressbook was not successful." : "启用切换地址簿未成功。",
     "This will delete the addressbook and every contacts within it" : "这将删除地址簿及其中所有联系人",
     "Delete {addressbook} ?" : "删除 {addressbook} ？",
@@ -139,6 +139,8 @@ OC.L10N.register(
     "None" : "无",
     "Unknown" : "未知",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 联系人读取失败"],
-    "An error occurred" : "发生错误"
+    "An error occurred" : "发生错误",
+    "Your web browser is out of date" : "您的浏览器版本太旧",
+    "This application is not compatible with Internet Explorer" : "此应用与Internet Explorer不兼容"
 },
 "nplurals=1; plural=0;");
